#!/bin/bash

LOG_PATH='/tmp/mcr_operation.log'


file_lock_check() {
	exec 1001>>/var/lock/mcr.lock
	flock -n 1001	
	if [[ $? -ne 0 ]]; then
cat << EOF
warning: Can not create transaction lock on /var/lock/mcr.lock (MCR call)
	 Please confirm that no other scripts from the MCR package are currently running.
	 If there are no such scripts running, please use the following command to unlock:
	 rm /var/lock/mcr.lock

EOF
		exit 1
	fi
}

function die() {
	echo $1
	exit 1
}

function usage() {
cat << EOF
Usage : `basename $0` {options}
options:
	start: load mcr driver modules
	stop: unload mcr driver mudules
EOF
}

function check_module_exist() {
	local ko_name=$1

	modinfo $ko_name >> $LOG_PATH 2>&1
	if [ $? -eq 0 ]; then
		return 0
	else
		return 1
	fi
}

function load_module() {
	local ko_name=$1

	check_module_exist $ko_name
	if [ $? -ne 0 ]; then
		die "The module $ko_name does not exist. Please reinstall MCR packages and retry."
	fi
	modprobe $ko_name >> $LOG_PATH 2>&1
	return $?
}

function unload_module() {
	local ko_name=$1

	lsmod | awk '{print $1}'|grep $ko_name -w >> $LOG_PATH 2>&1
	if [ $? -eq 0 ]; then
		modprobe -r $ko_name >> $LOG_PATH 2>&1
		if [ $? -ne 0 ]; then
			die "Failed to unload module $ko_name."
			return 1
		else
			return 0
		fi
	else
		return 0
	fi
}

function start() {
	file_lock_check
	load_module xsc_pci && load_module xsc_eth && load_module xsc_ib
	rm /var/lock/mcr.lock
}

function stop() {
	file_lock_check
	unload_module xsc_ib && unload_module xsc_eth && unload_module xsc_pci
	rm /var/lock/mcr.lock
}

function init() {
	echo -n "" > $LOG_PATH
}

function main() {
	while [ ! -z "$1" ]; do
		case "$1" in
		-h | --help)
			usage
			shift
			exit 0
			;;
		start)
			start
			shift
			;;
		stop)
			stop
			shift
			;;
		*)
			usage
			shift
			exit 1
			;;
		esac
	done
}

main $@


